==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/admin/submit.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");

if (!KWL_CheckAdmin()) {
	KWL_AccessLog(_ACCESS_DENIED);
	die(_ACCESS_INVALID);
}

if ($what == "block") {
   if ($Type == 3) {
      switch ($system) {
         case 0: $SrcURL = "topic.php"; break;
         case 1: $SrcURL = "older.php"; break;
         case 2: $SrcURL = "top5.php";  break;
         case 3: $SrcURL = "hot5.php";  break;
         case 4: $SrcURL = "lastc5.php"; break;
			case 5: $SrcURL = "theme.php"; break;
			case 6: $SrcURL = "scroll.php"; break;
			case 7: $SrcURL = "login.php"; break;
			case 8: $SrcURL = "poll.php"; break;
			case 9: $SrcURL = "feature.php"; break;
			case 10: $SrcURL = "rlink.php"; break;
			case 11: $SrcURL = "rbutton.php"; break;
		}
		$Heading = KWL_SblockTitle($SrcURL);
	}
	if ($Type>0 && $Type<3 && !@fopen($SrcURL,"rb")) {
		$msg	= urlencode(_NOT_URL . " : <b>$SrcURL</b>");
		KWL_Redirect("admin/blocks.php?msg=$msg");
		exit();
	} 
	else if (!$Heading) KWL_ShowError(_SUGERROR);
	else {
	$sm		= ($ShowMain=="on" ? "1" : "0");
	$pc		= ($PageComments=="on" ? "1" : "0");
	$sql	= "INSERT INTO T_Blocks ";
	$sql	.= "(Rid,Heading,Content,URL,Display,ShowMain,PageComments,Cache,Type,Hits,OrderID,Birthstamp,Timestamp,MaxItem) ";
	$sql	.= "VALUES (";
	$sql	.= "'" . KWL_getRid() . "',";
	$sql	.= "'" . $Heading . "',";
	$sql	.= "'" . $Content . "',";
	$sql	.= "'" . $SrcURL . "',";
	$sql	.= "'" . $Display . "',";
	$sql	.= "'" . $sm . "',";
	$sql	.= "'" . $pc . "',";
	$sql	.= "'" . $Cache . "',";
	$sql	.= $Type . ",";
	$sql	.= "0,";
	$sql	.= $OrderID . ",";
	$sql	.= "now(),";
	$sql	.= "now(), $MaxItem )";
	$RET	= SqlQuery($sql);
	KWL_AccessLog(_ADD_BLOCK);
	if ($RET<1) {
		KWL_ErrorLog(_UNABLE_BLOCK);
	}
	}
	KWL_Redirect("admin/blocks.php");

} elseif ($what == "topic") {

	$NoPosting = !empty($NoPosting) ? 1 : 0;
	$NoComments = !empty($NoComments) ? 1 : 0;

	$sql	= "INSERT INTO T_Topics ";
	$sql	.= "(Topic,ImgURL,AltTag,NoPosting,NoComments,Timestamp,OrderID) ";
	$sql	.= "VALUES (";
	$sql	.= "'" . $Topic . "',";
	$sql	.= "'" . $ImgURL . "',";
	$sql	.= "'" . $AltTag . "',";
	$sql	.= "'" . $NoPosting . "',";
	$sql	.= "'" . $NoComments . "',";
	$sql	.= "now(), ";
	$sql	.= "'$OrderID'";
	$sql	.= ")";
	$RET	= SqlQuery($sql);
	KWL_AccessLog(_ADD_TOPIC . " - $Topic");
	if ($RET<1) {
		KWL_ErrorLog(_UNABLE_TOPIC);
	}
	KWL_Redirect("admin/topics.php");

} elseif ($what == "layout") {
	switch ($layout_mode) {
	case "View/Load":
		KWL_Redirect("admin/layout.php?preview_layout=$name");
	break;

	case "Kill":
		if ($name==$CONF["Layout"]) {
			$msg	= urlencode(_NOTKILL);
			KWL_Redirect("admin/layout.php?msg=$msg");
		} else {
			$foo	= $CONF[G_PATH] . "/backend/layouts/" . $name . ".xlay";
			$RET	= unlink($foo);
			if ($RET<1) {
				KWL_ErrorLog(_UNABLE_DEL_LAYOUT);
			} else {
				$msg	= urlencode("Layout deleted: <b>$foo</b>.");
				KWL_Redirect("admin/layout.php?msg=$msg");
			}
		}
		KWL_AccessLog(_DELETE_LAYOUT . " $name");
	break;

	case "Add/Update":
		KWL_ExportLayout($_POST);
		$foo	= $CONF[G_PATH] . "/backend/layouts/" . $Layout . ".xlay";
		$msg	= urlencode(_LAYOUT_ADDED . " <b>$foo</b>.");
		KWL_AccessLog(_UPDATE_LAYOUT . " $Layout");
		KWL_Redirect("admin/layout.php?preview_layout=$Layout&msg=$msg");
	break;
	}

} elseif ($what == "config-site") {

   if ($_POST['NoLogin_User']) $_POST['NoLogin_User'] = 1;
   else $_POST['NoLogin_User'] = 0;

	$tmp	= urlencode(_SAVED);
	if (!empty($Passwd) || !empty($Passwd2)) {
		if ($_POST['Passwd'] == $_POST['Passwd2']) {
			$sql	= "UPDATE T_Config set ";
			$sql	.= "Value = '" . md5($_POST['Passwd']) . "' ";
	 		$sql    .= "WHERE Name = 'Passwd'";    
			$RET	= SqlQuery($sql);
		} else {
			$tmp	= urlencode(_SAVEDNOPW);
		}
	}
	for (reset($_POST);$k=key($_POST);next($_POST)) {
		if ($k!="what" && $k!="Passwd" && $k!="Passwd2" && $k!="korweblog_new_theme" && $k!="theme_array") {
			if (SqlCount("T_Config","Name",$k)) {
				$sql	= "UPDATE T_Config set ";
				$sql	.= "Value = '" . $_POST[$k] . "' ";
				$sql    .= "WHERE Name = '" . $k . "'";    
				SqlQuery($sql);
			} else {
				$sql  = "INSERT INTO T_Config (Name,Value) ";
				$sql .= "VALUES ('$k','$_POST[$k]')";
				SqlQuery($sql);
			}
		}
	}
   if (!count($theme_array)) $theme_array = array("$Layout");
   SqlQuery("UPDATE T_Config SET Value = '". serialize($theme_array) ."' WHERE Name = 'active_theme'");
   if ($_COOKIE['KorWebLog'] != KWL_Rot13($SiteKey)) {
		$name   = $SiteKey . "_admin";
		setcookie(md5($name),md5(KWL_Rot13($SiteKey)),0,"/","",0);
	}
	KWL_AccessLog(_UPDATE_SITE);
	KWL_Redirect("admin/config-site.php?msg=$tmp");

} elseif ($what == "config-story") {

	update_site_config($_POST,$what,_STORYCONT);

} elseif ($what == "config-reply") {

	update_site_config($_POST,$what,_REPLYCONT);

} elseif ($what == "config-extend") {

	update_site_config($_POST,$what,_EXTCONT);

} elseif ($what == "config-more") {

	update_site_config($_POST,$what,_NEWCONT);

} elseif ($what == "user-ext") {

	update_site_config($_POST,$what);

} elseif ($what == "autostory") {

	update_site_config($_POST,$what);

} elseif ($what == "download") {

	update_site_config($_POST,$what);

} elseif ($what == "story-link") {

	$tmp	= urlencode(_SAVED);
	for (reset($_POST);$k=key($_POST);next($_POST)) {
		if ($k != "what" && !empty($IndexName)) {
			$sql	= "INSERT INTO T_IndexNames (Name) VALUES ('$IndexName')";
			SqlQuery($sql);
			$IndexName  = "";
		}
	}
	# kill link index name
	if (!empty($IndexKills) && $action=="kill") {
		$sql	= "DELETE FROM T_IndexNames WHERE Rid=0 ";
		for ($i=0;$i<count($IndexKills);$i++) {
			$sql	.= "OR Name='$IndexKills[$i]'";
		}
		SqlQuery($sql);
		# kill all associated story links as well
		$sql	= "DELETE FROM T_IndexLinks WHERE Rid=0 ";
		for ($i=0;$i<count($IndexKills);$i++) {
			$sql	.= "OR Name='$IndexKills[$i]'";
		}
		SqlQuery($sql);
	}

	KWL_AccessLog(_UPDATE_EXT_CONF);
	KWL_Redirect("admin/story-link.php?msg=$tmp");

} elseif ($what == "poll") {

	KWL_AccessLog(_UPDATE_POLL . " $Rid");
	$A[1] = $Aid1;
	$A[2] = $Aid2;
	$A[3] = $Aid3;
	$A[4] = $Aid4;
	$A[5] = $Aid5;
	$A[6] = $Aid6;
	$A[7] = $Aid7;
	$A[8] = $Aid8;
	$A[9] = $Aid9;
	$A[10] = $Aid10;
	$V[1] = $Votes1;
	$V[2] = $Votes2;
	$V[3] = $Votes3;
	$V[4] = $Votes4;
	$V[5] = $Votes5;
	$V[6] = $Votes6;
	$V[7] = $Votes7;
	$V[8] = $Votes8;
	$V[9] = $Votes9;
	$V[10] = $Votes10;
	$Voters = 0;
	for ($i=1; $i<=10; $i++) {
		$Voters = $Voters + $V[$i];
	}

	if (!empty($Question)) {
	
	if (empty($Voters)) { $Voters = "0"; }
	$sql	= "DELETE FROM T_PollQuestions WHERE Rid = '$Rid'";
	$result = SqlQuery($sql);
	$sql	= "DELETE FROM T_PollAnswers WHERE Rid = '$Rid'";
	$result = SqlQuery($sql);

	$sql	= "INSERT INTO T_PollQuestions ";
	$sql	.= "(Rid, Question, Voters, ExpireDays, Birthstamp, Display) ";
	$sql	.= "VALUES (";
	$sql	.= "'" . $Rid . "',";
	$sql	.= "'" . $Question . "',";
	$sql	.= $Voters . ",";
	$sql	.= $Days . ",";
	$sql	.= "now(),";
	$sql	.= "'" . $Display . "')";
	$result = SqlQuery($sql);	
	for ($i = 1; $i <= 10; $i++) {
		if (!empty($A[$i])) {
			if (empty($V[$i])) { $V[$i] = "0"; }
			$sql 	= "INSERT INTO T_PollAnswers ";
			$sql	.= "(Rid, Aid, Answer, Votes) ";
			$sql	.= "VALUES (";
			$sql	.= "'" . $Rid . "',";
			$sql	.= $i . ",";
			$sql	.= "'" . $A[$i] . "',";
			$sql	.= $V[$i] . ")";
			$result = SqlQuery($sql);
		}
	}
	}
	KWL_Redirect("$where");
}

function update_site_config($value,$where,$log='') {
	$tmp	= urlencode(_SAVED);
	for (reset($value);$k=key($value);next($value)) {
		$k = trim($k);
		if ($k !="what" && $k != "korweblog_new_theme") {
			if (SqlCount("T_Config","Name",$k)) {
				$sql	= "UPDATE T_Config set ";
				$sql .= "Value = '" . $value[$k] . "' ";
				$sql .= "WHERE Name = '" . $k . "'";
				SqlQuery($sql);
			} else {
				$sql  = "INSERT INTO T_Config (Name,Value) ";
				$sql .= "VALUES ('$k','$value[$k]')";
				SqlQuery($sql);
			}
		}
	}
	if (!empty($log)) KWL_AccessLog($log . " " . _UPDATED);
	KWL_Redirect("admin/$where". ".php?msg=$tmp");
}

function KWL_ExportLayout($array) {
	global	$G_VER;
	$CONF = KWL_GetConf();	

	$outputfile	= "$CONF[G_PATH]/backend/layouts/$array[Layout]".".xlay";

	if (!$file=fopen($outputfile,"wb")) 
		KWL_ErrorLog(_UNABLE_WRITE . " $outputfile\n");
	else {
		fputs ($file, "<?xml version=\"1.0\"?>\n\n");
		fputs ($file, "<layout>\n\n");
		fputs ($file, "<info>\n");
		fputs ($file, "<author>$array[Author]</author>\n");
		fputs ($file, "<description>$array[Description]</description>\n");
		fputs ($file, "<version>$G_VER</version>\n");
		fputs ($file, "</info>\n\n");
		for (reset($array);$k=key($array);next($array)) {
			if (substr($k,0,5)=="XLAY_") {
				$tmp	= substr($k,5);
				fputs ($file, "<item>\n");
				$element = "<element>" . $tmp . "</element>\n";
				$value  = "<value>" . $array[$k] . "</value>\n";
				fputs ($file, $element);
				fputs ($file, $value);
				fputs ($file, "</item>\n\n");
			}
		}
	}
	fputs ($file, "</layout>\n");
	fclose($file);
}
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/admin/submit.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");

if (!KWL_CheckAdmin()) {
	KWL_AccessLog(_ACCESS_DENIED);
	die(_ACCESS_INVALID);
}

if ($what == "block") {
   if ($Type == 3) {
      switch ($system) {
         case 0: $SrcURL = "topic.php"; break;
         case 1: $SrcURL = "older.php"; break;
         case 2: $SrcURL = "top5.php";  break;
         case 3: $SrcURL = "hot5.php";  break;
         case 4: $SrcURL = "lastc5.php"; break;
			case 5: $SrcURL = "theme.php"; break;
			case 6: $SrcURL = "scroll.php"; break;
			case 7: $SrcURL = "login.php"; break;
			case 8: $SrcURL = "poll.php"; break;
			case 9: $SrcURL = "feature.php"; break;
			case 10: $SrcURL = "rlink.php"; break;
			case 11: $SrcURL = "rbutton.php"; break;
		}
		$Heading = KWL_SblockTitle($SrcURL);
	}
	if ($Type>0 && $Type<3 && !@fopen($SrcURL,"rb")) {
		$msg	= urlencode(_NOT_URL . " : <b>$SrcURL</b>");
		KWL_Redirect("admin/blocks.php?msg=$msg");
		exit();
	} 
	else if (!$Heading) KWL_ShowError(_SUGERROR);
	else {
	$sm		= ($ShowMain=="on" ? "1" : "0");
	$pc		= ($PageComments=="on" ? "1" : "0");
	$sql	= "INSERT INTO T_Blocks ";
	$sql	.= "(Rid,Heading,Content,URL,Display,ShowMain,PageComments,Cache,Type,Hits,OrderID,Birthstamp,Timestamp,MaxItem) ";
	$sql	.= "VALUES (";
	$sql	.= "'" . KWL_getRid() . "',";
	$sql	.= "'" . $Heading . "',";
	$sql	.= "'" . $Content . "',";
	$sql	.= "'" . $SrcURL . "',";
	$sql	.= "'" . $Display . "',";
	$sql	.= "'" . $sm . "',";
	$sql	.= "'" . $pc . "',";
	$sql	.= "'" . $Cache . "',";
	$sql	.= $Type . ",";
	$sql	.= "0,";
	$sql	.= $OrderID . ",";
	$sql	.= "now(),";
	$sql	.= "now(), $MaxItem )";
	$RET	= SqlQuery($sql);
	KWL_AccessLog(_ADD_BLOCK);
	if ($RET<1) {
		KWL_ErrorLog(_UNABLE_BLOCK);
	}
	}
	KWL_Redirect("admin/blocks.php");

} elseif ($what == "topic") {

	$NoPosting = !empty($NoPosting) ? 1 : 0;
	$NoComments = !empty($NoComments) ? 1 : 0;

	$sql	= "INSERT INTO T_Topics ";
	$sql	.= "(Topic,ImgURL,AltTag,NoPosting,NoComments,Timestamp,OrderID) ";
	$sql	.= "VALUES (";
	$sql	.= "'" . $Topic . "',";
	$sql	.= "'" . $ImgURL . "',";
	$sql	.= "'" . $AltTag . "',";
	$sql	.= "'" . $NoPosting . "',";
	$sql	.= "'" . $NoComments . "',";
	$sql	.= "now(), ";
	$sql	.= "'$OrderID'";
	$sql	.= ")";
	$RET	= SqlQuery($sql);
	KWL_AccessLog(_ADD_TOPIC . " - $Topic");
	if ($RET<1) {
		KWL_ErrorLog(_UNABLE_TOPIC);
	}
	KWL_Redirect("admin/topics.php");

} elseif ($what == "layout") {
	switch ($layout_mode) {
	case "View/Load":
		KWL_Redirect("admin/layout.php?preview_layout=$name");
	break;

	case "Kill":
		if ($name==$CONF["Layout"]) {
			$msg	= urlencode(_NOTKILL);
			KWL_Redirect("admin/layout.php?msg=$msg");
		} else {
			$foo	= $CONF[G_PATH] . "/backend/layouts/" . $name . ".xlay";
			$RET	= unlink($foo);
			if ($RET<1) {
				KWL_ErrorLog(_UNABLE_DEL_LAYOUT);
			} else {
				$msg	= urlencode("Layout deleted: <b>$foo</b>.");
				KWL_Redirect("admin/layout.php?msg=$msg");
			}
		}
		KWL_AccessLog(_DELETE_LAYOUT . " $name");
	break;

	case "Add/Update":
		KWL_ExportLayout($_POST);
		$foo	= $CONF[G_PATH] . "/backend/layouts/" . $Layout . ".xlay";
		$msg	= urlencode(_LAYOUT_ADDED . " <b>$foo</b>.");
		KWL_AccessLog(_UPDATE_LAYOUT . " $Layout");
		KWL_Redirect("admin/layout.php?preview_layout=$Layout&msg=$msg");
	break;
	}

} elseif ($what == "config-site") {

   if (isset($_POST['NoLogin_User'])) $_POST['NoLogin_User'] = 1;
   else $_POST['NoLogin_User'] = 0;

	$tmp	= urlencode(_SAVED);
	if (!empty($Passwd) || !empty($Passwd2)) {
		if ($_POST['Passwd'] == $_POST['Passwd2']) {
			$sql	= "UPDATE T_Config set ";
			$sql	.= "Value = '" . md5($_POST['Passwd']) . "' ";
	 		$sql    .= "WHERE Name = 'Passwd'";    
			$RET	= SqlQuery($sql);
		} else {
			$tmp	= urlencode(_SAVEDNOPW);
		}
	}
	for (reset($_POST);$k=key($_POST);next($_POST)) {
		if ($k!="what" && $k!="Passwd" && $k!="Passwd2" && $k!="korweblog_new_theme" && $k!="theme_array") {
			if (SqlCount("T_Config","Name",$k)) {
				$sql	= "UPDATE T_Config set ";
				$sql	.= "Value = '" . $_POST[$k] . "' ";
				$sql    .= "WHERE Name = '" . $k . "'";    
				SqlQuery($sql);
			} else {
				$sql  = "INSERT INTO T_Config (Name,Value) ";
				$sql .= "VALUES ('$k','$_POST[$k]')";
				SqlQuery($sql);
			}
		}
	}
   if (!count($theme_array)) $theme_array = array("$Layout");
   SqlQuery("UPDATE T_Config SET Value = '". serialize($theme_array) ."' WHERE Name = 'active_theme'");
   if (isset($_COOKIE['KorWebLog']) && $_COOKIE['KorWebLog'] != KWL_Rot13($SiteKey)) {
		$name   = $SiteKey . "_admin";
		setcookie(md5($name),md5(KWL_Rot13($SiteKey)),0,"/","",0);
	}
	KWL_AccessLog(_UPDATE_SITE);
	KWL_Redirect("admin/config-site.php?msg=$tmp");

} elseif ($what == "config-story") {

	update_site_config($_POST,$what,_STORYCONT);

} elseif ($what == "config-reply") {

	update_site_config($_POST,$what,_REPLYCONT);

} elseif ($what == "config-extend") {

	update_site_config($_POST,$what,_EXTCONT);

} elseif ($what == "config-more") {

	update_site_config($_POST,$what,_NEWCONT);

} elseif ($what == "user-ext") {

	update_site_config($_POST,$what);

} elseif ($what == "autostory") {

	update_site_config($_POST,$what);

} elseif ($what == "download") {

	update_site_config($_POST,$what);

} elseif ($what == "story-link") {

	$tmp	= urlencode(_SAVED);
	for (reset($_POST);$k=key($_POST);next($_POST)) {
		if ($k != "what" && !empty($IndexName)) {
			$sql	= "INSERT INTO T_IndexNames (Name) VALUES ('$IndexName')";
			SqlQuery($sql);
			$IndexName  = "";
		}
	}
	# kill link index name
	if (!empty($IndexKills) && $action=="kill") {
		$sql	= "DELETE FROM T_IndexNames WHERE Rid=0 ";
		for ($i=0;$i<count($IndexKills);$i++) {
			$sql	.= "OR Name='$IndexKills[$i]'";
		}
		SqlQuery($sql);
		# kill all associated story links as well
		$sql	= "DELETE FROM T_IndexLinks WHERE Rid=0 ";
		for ($i=0;$i<count($IndexKills);$i++) {
			$sql	.= "OR Name='$IndexKills[$i]'";
		}
		SqlQuery($sql);
	}

	KWL_AccessLog(_UPDATE_EXT_CONF);
	KWL_Redirect("admin/story-link.php?msg=$tmp");

} elseif ($what == "poll") {

	KWL_AccessLog(_UPDATE_POLL . " $Rid");
	$A[1] = $Aid1;
	$A[2] = $Aid2;
	$A[3] = $Aid3;
	$A[4] = $Aid4;
	$A[5] = $Aid5;
	$A[6] = $Aid6;
	$A[7] = $Aid7;
	$A[8] = $Aid8;
	$A[9] = $Aid9;
	$A[10] = $Aid10;
	$V[1] = $Votes1;
	$V[2] = $Votes2;
	$V[3] = $Votes3;
	$V[4] = $Votes4;
	$V[5] = $Votes5;
	$V[6] = $Votes6;
	$V[7] = $Votes7;
	$V[8] = $Votes8;
	$V[9] = $Votes9;
	$V[10] = $Votes10;
	$Voters = 0;
	for ($i=1; $i<=10; $i++) {
		$Voters = $Voters + $V[$i];
	}

	if (!empty($Question)) {
	
	if (empty($Voters)) { $Voters = "0"; }
	$sql	= "DELETE FROM T_PollQuestions WHERE Rid = '$Rid'";
	$result = SqlQuery($sql);
	$sql	= "DELETE FROM T_PollAnswers WHERE Rid = '$Rid'";
	$result = SqlQuery($sql);

	$sql	= "INSERT INTO T_PollQuestions ";
	$sql	.= "(Rid, Question, Voters, ExpireDays, Birthstamp, Display) ";
	$sql	.= "VALUES (";
	$sql	.= "'" . $Rid . "',";
	$sql	.= "'" . $Question . "',";
	$sql	.= $Voters . ",";
	$sql	.= $Days . ",";
	$sql	.= "now(),";
	$sql	.= "'" . $Display . "')";
	$result = SqlQuery($sql);	
	for ($i = 1; $i <= 10; $i++) {
		if (!empty($A[$i])) {
			if (empty($V[$i])) { $V[$i] = "0"; }
			$sql 	= "INSERT INTO T_PollAnswers ";
			$sql	.= "(Rid, Aid, Answer, Votes) ";
			$sql	.= "VALUES (";
			$sql	.= "'" . $Rid . "',";
			$sql	.= $i . ",";
			$sql	.= "'" . $A[$i] . "',";
			$sql	.= $V[$i] . ")";
			$result = SqlQuery($sql);
		}
	}
	}
	KWL_Redirect("$where");
}

function update_site_config($value,$where,$log='') {
	$tmp	= urlencode(_SAVED);
	for (reset($value);$k=key($value);next($value)) {
		$k = trim($k);
		if ($k !="what" && $k != "korweblog_new_theme") {
			if (SqlCount("T_Config","Name",$k)) {
				$sql	= "UPDATE T_Config set ";
				$sql .= "Value = '" . $value[$k] . "' ";
				$sql .= "WHERE Name = '" . $k . "'";
				SqlQuery($sql);
			} else {
				$sql  = "INSERT INTO T_Config (Name,Value) ";
				$sql .= "VALUES ('$k','$value[$k]')";
				SqlQuery($sql);
			}
		}
	}
	if (!empty($log)) KWL_AccessLog($log . " " . _UPDATED);
	KWL_Redirect("admin/$where". ".php?msg=$tmp");
}

function KWL_ExportLayout($array) {
	global	$G_VER;
	$CONF = KWL_GetConf();	

	$outputfile	= "$CONF[G_PATH]/backend/layouts/$array[Layout]".".xlay";

	if (!$file=fopen($outputfile,"wb")) 
		KWL_ErrorLog(_UNABLE_WRITE . " $outputfile\n");
	else {
		fputs ($file, "<?xml version=\"1.0\"?>\n\n");
		fputs ($file, "<layout>\n\n");
		fputs ($file, "<info>\n");
		fputs ($file, "<author>$array[Author]</author>\n");
		fputs ($file, "<description>$array[Description]</description>\n");
		fputs ($file, "<version>$G_VER</version>\n");
		fputs ($file, "</info>\n\n");
		for (reset($array);$k=key($array);next($array)) {
			if (substr($k,0,5)=="XLAY_") {
				$tmp	= substr($k,5);
				fputs ($file, "<item>\n");
				$element = "<element>" . $tmp . "</element>\n";
				$value  = "<value>" . $array[$k] . "</value>\n";
				fputs ($file, $element);
				fputs ($file, $value);
				fputs ($file, "</item>\n\n");
			}
		}
	}
	fputs ($file, "</layout>\n");
	fclose($file);
}
?>
